@@ -376,8 +376,10 @@ class DataFrame:
         return self.columns
     
     def from_pandas(self,df):
-        self.__stop_appending__()                  
+        self.__stop_appending__()     
         for name in df.columns:
+            if df[name].values.dtype == np.dtype('O'):
+                df[name] = df[name].fillna('')
             DataFrame.__setattr__(self,name , df[name].values)
         return self
     def where(self,boolean_array):
@@ -445,8 +447,7 @@ class DataFrame:
 
 def from_pandas(df):                  
     t = DataFrame()
-    for name in df.columns:
-        t[name] = df[name].values
+    t.from_pandas(df)
     return t
 
 def read_csv(path,skip_blank_lines = False,keep_default_na=False):
